#[repr(transparent)]pub struct Perm<Inner>(pub Inner);Expand description
generic Perm wrapper
Tuple Fields
0: InnerImplementations
Sourceimpl<I: Index, N: Shape> Perm<Own<I, N>>
impl<I: Index, N: Shape> Perm<Own<I, N>>
Sourcepub fn as_shape<M: Shape>(&self, dim: M) -> PermRef<'_, I, M>
pub fn as_shape<M: Shape>(&self, dim: M) -> PermRef<'_, I, M>
returns the input permutation with the given shape after checking that it matches the current shape
Sourcepub fn into_shape<M: Shape>(self, dim: M) -> Perm<I, M>
pub fn into_shape<M: Shape>(self, dim: M) -> Perm<I, M>
returns the input permutation with the given shape after checking that it matches the current shape
Sourcepub fn new_checked(
forward: Box<[Idx<N, I>]>,
inverse: Box<[Idx<N, I>]>,
dim: N,
) -> Self
pub fn new_checked( forward: Box<[Idx<N, I>]>, inverse: Box<[Idx<N, I>]>, dim: N, ) -> Self
creates a new permutation, by checking the validity of the inputs
panics
the function panics if any of the following conditions are violated:
forward and inverse must have the same length which must be less than or equal to
I::Signed::MAX, be valid permutations, and be inverse permutations of each other
Sourcepub unsafe fn new_unchecked(
forward: Box<[Idx<N, I>]>,
inverse: Box<[Idx<N, I>]>,
) -> Self
pub unsafe fn new_unchecked( forward: Box<[Idx<N, I>]>, inverse: Box<[Idx<N, I>]>, ) -> Self
creates a new permutation reference, without checking the validity of the inputs
safety
forward and inverse must have the same length which must be less than or equal to
I::Signed::MAX, be valid permutations, and be inverse permutations of each other
Sourcepub fn into_arrays(self) -> (Box<[Idx<N, I>]>, Box<[Idx<N, I>]>)
pub fn into_arrays(self) -> (Box<[Idx<N, I>]>, Box<[Idx<N, I>]>)
returns the permutation as an array
Sourcepub fn into_inverse(self) -> Self
pub fn into_inverse(self) -> Self
returns the inverse permutation
Sourceimpl<I: Index, N: Shape, Inner: for<'short> Reborrow<'short, Target = Ref<'short, I, N>>> Perm<Inner>
impl<I: Index, N: Shape, Inner: for<'short> Reborrow<'short, Target = Ref<'short, I, N>>> Perm<Inner>
Sourceimpl<'a, I: Index, N: Shape> Perm<Ref<'a, I, N>>
impl<'a, I: Index, N: Shape> Perm<Ref<'a, I, N>>
Sourcepub fn as_shape<M: Shape>(self, dim: M) -> PermRef<'a, I, M>
pub fn as_shape<M: Shape>(self, dim: M) -> PermRef<'a, I, M>
returns the input permutation with the given shape after checking that it matches the current shape
Sourcepub fn new_checked(
forward: &'a [Idx<N, I>],
inverse: &'a [Idx<N, I>],
dim: N,
) -> Self
pub fn new_checked( forward: &'a [Idx<N, I>], inverse: &'a [Idx<N, I>], dim: N, ) -> Self
creates a new permutation, by checking the validity of the inputs
panics
the function panics if any of the following conditions are violated:
forwardandinversemust have the same length which must be less than or equal toI::Signed::MAX, be valid permutations, and be inverse permutations of each other
Sourcepub unsafe fn new_unchecked(
forward: &'a [Idx<N, I>],
inverse: &'a [Idx<N, I>],
dim: N,
) -> Self
pub unsafe fn new_unchecked( forward: &'a [Idx<N, I>], inverse: &'a [Idx<N, I>], dim: N, ) -> Self
creates a new permutation reference, without checking the validity of the inputs
safety
forward and inverse must have the same length which must be less than or equal to
I::Signed::MAX, be valid permutations, and be inverse permutations of each other
Sourcepub fn canonicalized(self) -> PermRef<'a, I::FixedWidth, N>
pub fn canonicalized(self) -> PermRef<'a, I::FixedWidth, N>
cast the permutation to the fixed width index type
Sourcepub fn uncanonicalized<J: Index>(self) -> PermRef<'a, J, N>
pub fn uncanonicalized<J: Index>(self) -> PermRef<'a, J, N>
cast the permutation from the fixed width index type
Sourceimpl<Inner> Perm<Inner>
impl<Inner> Perm<Inner>
Sourcepub fn from_inner_ref(inner: &Inner) -> &Self
pub fn from_inner_ref(inner: &Inner) -> &Self
wrap by reference
Sourcepub fn from_inner_mut(inner: &mut Inner) -> &mut Self
pub fn from_inner_mut(inner: &mut Inner) -> &mut Self
wrap by mutable reference